package org.opengroup.osdu.register.provider.gcp.verifier;

import java.util.Collections;

import org.opengroup.osdu.register.provider.interfaces.verifier.GsaTokenVerifier;
import org.opengroup.osdu.register.utils.AppServiceConfig;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.google.api.client.googleapis.auth.oauth2.GoogleIdToken;
import com.google.api.client.googleapis.auth.oauth2.GoogleIdTokenVerifier;
import com.google.api.client.http.javanet.NetHttpTransport;
import com.google.api.client.json.jackson2.JacksonFactory;
import com.google.common.base.Strings;

@Component
public class GsaTokenVerifierImpl implements GsaTokenVerifier {

  @Autowired
  private AppServiceConfig serviceConfig;

  public boolean verify(String token) {
    if (Strings.isNullOrEmpty(token)) {
      return true;
    }
    try {
      GoogleIdTokenVerifier verifier = new GoogleIdTokenVerifier.Builder(new NetHttpTransport(),
          JacksonFactory.getDefaultInstance())
          .setAudience(Collections.singletonList(this.serviceConfig.getIntegrationTestJwtAudiences()))
          .build();
      GoogleIdToken idToken = verifier.verify(token);
      return idToken != null;
    } catch (Exception ex) {
      return false;
    }
  }
}
